@@ -23,17 +23,18 @@ class TwitterError(Exception):
     pass
 
 class TwitterCall(object):
-    def __init__(self, username, password, format, uri=""):
+    def __init__(self, username, password, format, domain, uri=""):
         self.username = username
         self.password = password
         self.format = format
         self.uri = uri
+        self.domain = domain
     def __getattr__(self, k):
         try:
             return object.__getattr__(self, k)
         except AttributeError:
             return TwitterCall(
-                self.username, self.password, self.format, 
+                self.username, self.password, self.format, self.domain,
                 self.uri + "/" + k)
     def __call__(self, **kwargs):
         method = "GET"
@@ -56,7 +57,7 @@ class TwitterCall(object):
             headers["Content-type"] = "application/x-www-form-urlencoded"
             headers["Content-length"] = len(encoded_kwargs)
         
-        c = httplib.HTTPConnection("twitter.com")
+        c = httplib.HTTPConnection(self.domain)
         try:
             c.putrequest(method, "%s.%s%s" %(
                 self.uri, self.format, argStr))
@@ -87,7 +88,9 @@ class Twitter(TwitterCall):
     is decoded python objects (lists and dicts).
 
     The Twitter API is documented here:
-    http://groups.google.com/group/twitter-development-talk/web/api-documentation
+
+        http://apiwiki.twitter.com/
+        http://groups.google.com/group/twitter-development-talk/web/api-documentation
     
     Examples::
     
@@ -107,6 +110,16 @@ class Twitter(TwitterCall):
           user="billybob",
           text="I think yer swell!")
 
+    Searching Twitter::
+        
+        twitter_search = Twitter(domain="search.twitter.com")
+
+        # Find the latest search trends
+        twitter_search.trends()
+
+        # Search for the latest News on #gaza
+        twitter_search(q="#gaza")
+
     Using the data returned::
 
       Twitter API calls return decoded JSON. This is converted into
@@ -130,7 +143,7 @@ class Twitter(TwitterCall):
       The output will not be parsed in any way. It will be a raw string
       of XML.
     """
-    def __init__(self, email=None, password=None, format="json"):
+    def __init__(self, email=None, password=None, format="json", domain="twitter.com"):
         """
         Create a new twitter API connector using the specified
         credentials (email and password). Format specifies the output
@@ -138,6 +151,6 @@ class Twitter(TwitterCall):
         """
         if (format not in ("json", "xml")):
             raise TwitterError("Unknown data format '%s'" %(format))
-        TwitterCall.__init__(self, email, password, format)
+        TwitterCall.__init__(self, email, password, format, domain)
 
 __all__ = ["Twitter", "TwitterError"]
